"""ETS Project Parser is a library to parse ETS project files."""
# flake8: noqa
from .xknxproj import XKNXProj

__all__ = [
    "XKNXProj",
]
